==> apache-mxnet-src-1.8.0-incubating.tar.gz: apache-mxnet-src-1.8.0-incubating/docs/static_site/src/_includes/get_started/linux/python/gpu/pip.md <==
WARNING: the following PyPI package names are provided for your convenience but
they point to packages that are *not* provided nor endorsed by the Apache
Software Foundation. As such, they might contain software components with more
restrictive licenses than the Apache License and you'll need to decide whether
they are appropriate for your usage. The packages linked here contain
proprietary parts of the NVidia CUDA SDK and GPL GCC Runtime Library components.
Like all Apache Releases, the official Apache MXNet (incubating) releases
consist of source code only and are found at the [Download
page](https://mxnet.apache.org/get_started/download).

Run the following command:

<div class="v1-7-0">
{% highlight bash %}
$ pip install mxnet-cu102
{% endhighlight %}

</div> <!-- End of v1-6-0 -->

<div class="v1-6-0">
{% highlight bash %}
$ pip install mxnet-cu102==1.6.0
{% endhighlight %}

</div> <!-- End of v1-6-0 -->

<div class="v1-5-1">
{% highlight bash %}
$ pip install mxnet-cu101==1.5.1
{% endhighlight %}

</div> <!-- End of v1-5-1 -->
<div class="v1-4-1">

{% highlight bash %}
$ pip install mxnet-cu101==1.4.1
{% endhighlight %}

</div> <!-- End of v1-4-1 -->
<div class="v1-3-1">

{% highlight bash %}
$ pip install mxnet-cu92==1.3.1
{% endhighlight %}

</div> <!-- End of v1-3-1-->
<div class="v1-2-1">

{% highlight bash %}
$ pip install mxnet-cu92==1.2.1
{% endhighlight %}

</div> <!-- End of v1-2-1-->

<div class="v1-1-0">

{% highlight bash %}
$ pip install mxnet-cu91==1.1.0
{% endhighlight %}

</div> <!-- End of v1-1-0-->

<div class="v1-0-0">

{% highlight bash %}
$ pip install mxnet-cu90==1.0.0
{% endhighlight %}

</div> <!-- End of v1-0-0-->

<div class="v0-12-1">

{% highlight bash %}
$ pip install mxnet-cu90==0.12.1
{% endhighlight %}

</div> <!-- End of v0-12-1-->

<div class="v0-11-0">

{% highlight bash %}
$ pip install mxnet-cu80==0.11.0
{% endhighlight %}

</div> <!-- End of v0-11-0-->

<br>

{% include /get_started/pip_snippet.md %}
{% include /get_started/gpu_snippet.md %}

==> apache-mxnet-src-1.9.1-incubating.tar.gz: apache-mxnet-src-1.9.1-incubating/docs/static_site/src/_includes/get_started/linux/python/gpu/pip.md <==
WARNING: the following PyPI package names are provided for your convenience but
they point to packages that are *not* provided nor endorsed by the Apache
Software Foundation. As such, they might contain software components with more
restrictive licenses than the Apache License and you'll need to decide whether
they are appropriate for your usage. The packages linked here contain
proprietary parts of the NVidia CUDA SDK and GPL GCC Runtime Library components.
Like all Apache Releases, the official Apache MXNet (incubating) releases
consist of source code only and are found at the [Download
page](https://mxnet.apache.org/get_started/download).

Run the following command:

<div class="v1-9-0">
{% highlight bash %}
$ pip install mxnet-cu102
{% endhighlight %}

</div> <!-- End of v1-9-0 -->

<div class="v1-8-0">
{% highlight bash %}
$ pip install mxnet-cu102==1.8.0.post0
{% endhighlight %}

</div> <!-- End of v1-8-0 -->

<div class="v1-7-0">
{% highlight bash %}
$ pip install mxnet-cu102==1.7.0
{% endhighlight %}

</div> <!-- End of v1-7-0 -->

<div class="v1-6-0">
{% highlight bash %}
$ pip install mxnet-cu102==1.6.0
{% endhighlight %}

</div> <!-- End of v1-6-0 -->

<div class="v1-5-1">
{% highlight bash %}
$ pip install mxnet-cu101==1.5.1
{% endhighlight %}

</div> <!-- End of v1-5-1 -->
<div class="v1-4-1">

{% highlight bash %}
$ pip install mxnet-cu101==1.4.1
{% endhighlight %}

</div> <!-- End of v1-4-1 -->
<div class="v1-3-1">

{% highlight bash %}
$ pip install mxnet-cu92==1.3.1
{% endhighlight %}

</div> <!-- End of v1-3-1-->
<div class="v1-2-1">

{% highlight bash %}
$ pip install mxnet-cu92==1.2.1
{% endhighlight %}

</div> <!-- End of v1-2-1-->

<div class="v1-1-0">

{% highlight bash %}
$ pip install mxnet-cu91==1.1.0
{% endhighlight %}

</div> <!-- End of v1-1-0-->

<div class="v1-0-0">

{% highlight bash %}
$ pip install mxnet-cu90==1.0.0
{% endhighlight %}

</div> <!-- End of v1-0-0-->

<div class="v0-12-1">

{% highlight bash %}
$ pip install mxnet-cu90==0.12.1
{% endhighlight %}

</div> <!-- End of v0-12-1-->

<div class="v0-11-0">

{% highlight bash %}
$ pip install mxnet-cu80==0.11.0
{% endhighlight %}

</div> <!-- End of v0-11-0-->

<br>

{% include /get_started/pip_snippet.md %}
{% include /get_started/gpu_snippet.md %}
